@@ -23,15 +23,6 @@ has 'border' => (
     default => sub { Graphics::Primitive::Border->new },
     trigger => sub { my ($self) = @_; $self->prepared(0); }
 );
-has 'callback' => (
-    traits => ['Code'],
-    is => 'rw',
-    isa => 'CodeRef',
-    predicate => 'has_callback',
-    handles => {
-        fire_callback => 'execute'
-    }
-);
 has 'class' => ( is => 'rw', isa => 'Str' );
 has 'color' => (
     is => 'rw', isa => 'Graphics::Color',
@@ -42,7 +33,7 @@ has 'height' => (
     is => 'rw',
     isa => 'Num',
     default => sub { 0 },
-    trigger => sub { my ($self) = @_; $self->prepared(0); }
+    trigger => sub { my ($self) = @_; $self->prepared(0); if($self->height < $self->minimum_height) { $self->height($self->minimum_height); } }
 );
 has 'margins' => (
     is => 'rw',
@@ -89,7 +80,7 @@ has 'width' => (
     is => 'rw',
     isa => 'Num',
     default => sub { 0 },
-    trigger => sub { my ($self) = @_; $self->prepared(0); }
+    trigger => sub { my ($self) = @_; $self->prepared(0); if($self->width < $self->minimum_width) { $self->width($self->minimum_width); } }
 );
 
 sub get_tree {
@@ -218,11 +209,7 @@ sub outside_height {
     return $w;
 }
 
-sub finalize {
-    my ($self) = @_;
-
-    $self->fire_callback($self) if $self->has_callback;
-}
+sub finalize { }
 
 sub prepare {
     my ($self, $driver) = @_;
@@ -341,16 +328,6 @@ Set this component's background color.
 Set this component's border, which should be an instance of
 L<Border|Graphics::Primitive::Border>.
 
-=item I<callback>
-
-Optional callback that is fired at the beginning of the C<finalize> phase.
-This allows you to add some sort of custom code that can modify the component
-just before it is rendered.  The only argument is the component itself.
-
-Note that changing the position or the dimensions of the component will B<not>
-re-layout the scene.  You may have weird results of you manipulate the
-component's dimensions here.
-
 =item I<class>
 
 Set/Get this component's class, which is an abitrary string.
@@ -361,19 +338,11 @@ outside use.
 
 Set this component's foreground color.
 
-=item I<fire_callback>
-
-Method to execute this component's C<callback>.
-
 =item I<get_tree>
 
 Get a tree for this component.  Since components are -- by definiton -- leaf
 nodes, this tree will only have the one member at it's root.
 
-=item I<has_callback>
-
-Predicate that tells if this component has a C<callback>.
-
 =item I<height>
 
 Set this component's height.
@@ -507,4 +476,4 @@ automatically be notified of progress on your bug as I make changes.
 Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
